@@ -32,8 +32,18 @@ class CreateServiceRequest(RoaRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_body(self): # string
+	def get_Develop(self): # String
+		return self.get_query_params().get('Develop')
+
+	def set_Develop(self, Develop):  # String
+		self.add_query_param('Develop', Develop)
+	def get_body(self): # String
 		return self.get_body_params().get('body')
 
-	def set_body(self, body):  # string
+	def set_body(self, body):  # String
 		self.add_body_params('body', body)
+	def get_Labels(self): # String
+		return self.get_query_params().get('Labels')
+
+	def set_Labels(self, Labels):  # String
+		self.add_query_param('Labels', Labels)
